﻿using EmbedIO;
using EmbedIO.Routing;
using EmbedIO.WebApi;
using Kyubey.Database;

namespace Kyubey;

public class ServerApiController : WebApiController
{
    public record ApiCreateUserRequestData
    {
        public required string Username { get; set; }
        public required string Password { get; set; }
        public required string RankingName { get; set; }
    }
    
    [Route(HttpVerbs.Post, "/create_user")]
    public async Task<string> Signup([JsonData] ApiCreateUserRequestData data)
    {
        if (JewelDbContext.Users.Exists(e => e.Username == data.Username || e.RankingName == data.RankingName))
        {
            throw HttpException.BadRequest("Username and rankingname must be unique");
        }

        var hashedPassword = Utils.ComputeHash(data.Password);

        var userObject = new User()
        {
            Username = data.Username,
            Password = hashedPassword,
            RankingName = data.RankingName
        };

        var id = JewelDbContext.Users.Insert(userObject).AsObjectId;
        return $"ok; id={id}";
    }
}